# coding: utf-8

"""
    Wink Payment API

    A programmatic way to create bookings, receive reactive and disburse funds globally.  ## APIs Not every integrator needs every APIs. For that reason, we have separated APIs into context.  - [Affiliate](/affiliate): All APIs related to selling travel inventory as an affiliate. - [Analytics](/analytics): All APIs related to tracking metrics across a wide variety of data source segments including, more entertaining, leaderboard metrics. - [Booking](/booking): All APIs related to creating platform bookings. - [Channel Manager](/channel-manager): All APIs related to channel managers who want to integrate with our platform. - [Extranet](/extranet): All APIs related to managing travel inventory and suppliers. - [Inventory](/inventory): All APIs related to retrieve known travel inventory as it was found using the Lookup API.. - [Lookup](/lookup): All APIs related to locating inventory by region, locale and property flags. - [Reference](/reference): All APIs related to retrieving platform-supported taxonomies. - [TripPay](/reactive): All APIs related to TripPay account management, booking, mapping and integration features.  ## SDKs We are actively working on supporting the most used languages out there. If you don't see your language here, reach out to us with a request to officially add your language. In the meantime, if you want to roll your own SDK, you can do so by downloading the OpenAPI spec and using one of the many available OpenAPI generators available: [https://openapi-generator.tech/docs/generators](https://openapi-generator.tech/docs/generators).  - Java SDK [https://github.com/wink-travel/trip-pay-sdk-java](https://github.com/wink-travel/trip-pay-sdk-java)  # Usage These features are made available to you via a [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer). This API is language agnostic. We will link to SDKs for the most popular programming languages on this page as they become available.  ## Versioning We chose to version our endpoints in a way that we hope affects your integration with us the least. You request the version of our API you wish to work with via the `Wink-Version` header. When it's time for you to upgrade, you only have to change the version number to get access to our updated endpoints.  ## Release history - Follow updates on Github: https://github.com/wink-travel/wink-sdk-java/blob/master/CHANGELOG.md 

    The version of the OpenAPI document: 30.9.11
    Contact: bjorn@wink.travel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trip_pay_payment.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_check_account_status(self) -> None:
        """Test case for check_account_status

        Check Account Status
        """
        pass

    def test_check_external_account_status(self) -> None:
        """Test case for check_external_account_status

        Check External Account Status
        """
        pass

    def test_create_account(self) -> None:
        """Test case for create_account

        Create Account
        """
        pass

    def test_create_account_bank_account(self) -> None:
        """Test case for create_account_bank_account

        Add Bank Account
        """
        pass

    def test_create_external_account_bank_account(self) -> None:
        """Test case for create_external_account_bank_account

        Add Bank Account to External
        """
        pass

    def test_delete_account(self) -> None:
        """Test case for delete_account

        Delete Account
        """
        pass

    def test_is_account_name_unique(self) -> None:
        """Test case for is_account_name_unique

        Verify Account Name
        """
        pass

    def test_load_account(self) -> None:
        """Test case for load_account

        Show Account
        """
        pass

    def test_load_account_by_name(self) -> None:
        """Test case for load_account_by_name

        Show Accounts by Name
        """
        pass

    def test_load_account_by_name_like(self) -> None:
        """Test case for load_account_by_name_like

        Show Accounts by Name like
        """
        pass

    def test_load_account_grid_for_authenticated_user(self) -> None:
        """Test case for load_account_grid_for_authenticated_user

        Show Account Grid for User
        """
        pass

    def test_load_accounts_for_authenticated_user(self) -> None:
        """Test case for load_accounts_for_authenticated_user

        Show Account for User
        """
        pass

    def test_load_external_account(self) -> None:
        """Test case for load_external_account

        Show Account for External
        """
        pass

    def test_remove_account_bank_account(self) -> None:
        """Test case for remove_account_bank_account

        Remove Bank Account
        """
        pass

    def test_remove_external_account_bank_account(self) -> None:
        """Test case for remove_external_account_bank_account

        Remove Bank Account for External
        """
        pass

    def test_search_account_by_name(self) -> None:
        """Test case for search_account_by_name

        Search Accounts by Name
        """
        pass

    def test_show_accounts_by_owner(self) -> None:
        """Test case for show_accounts_by_owner

        Show Accounts by Owner
        """
        pass

    def test_update_account(self) -> None:
        """Test case for update_account

        Update Account
        """
        pass

    def test_update_external_account(self) -> None:
        """Test case for update_external_account

        Update External Account
        """
        pass

    def test_update_national_identifier(self) -> None:
        """Test case for update_national_identifier

        Submit Tax ID
        """
        pass

    def test_upsert_account_bank_account(self) -> None:
        """Test case for upsert_account_bank_account

        Update Bank Account
        """
        pass

    def test_upsert_external_account_bank_account(self) -> None:
        """Test case for upsert_external_account_bank_account

        Update Bank Account for External
        """
        pass

    def test_verify_account(self) -> None:
        """Test case for verify_account

        Verify Account
        """
        pass


if __name__ == '__main__':
    unittest.main()
