# coding: utf-8

"""
    Wink Payment API

    A programmatic way to create bookings, receive reactive and disburse funds globally.  ## APIs Not every integrator needs every APIs. For that reason, we have separated APIs into context.  - [Affiliate](/affiliate): All APIs related to selling travel inventory as an affiliate. - [Analytics](/analytics): All APIs related to tracking metrics across a wide variety of data source segments including, more entertaining, leaderboard metrics. - [Booking](/booking): All APIs related to creating platform bookings. - [Channel Manager](/channel-manager): All APIs related to channel managers who want to integrate with our platform. - [Extranet](/extranet): All APIs related to managing travel inventory and suppliers. - [Inventory](/inventory): All APIs related to retrieve known travel inventory as it was found using the Lookup API.. - [Lookup](/lookup): All APIs related to locating inventory by region, locale and property flags. - [Reference](/reference): All APIs related to retrieving platform-supported taxonomies. - [TripPay](/reactive): All APIs related to TripPay account management, booking, mapping and integration features.  ## SDKs We are actively working on supporting the most used languages out there. If you don't see your language here, reach out to us with a request to officially add your language. In the meantime, if you want to roll your own SDK, you can do so by downloading the OpenAPI spec and using one of the many available OpenAPI generators available: [https://openapi-generator.tech/docs/generators](https://openapi-generator.tech/docs/generators).  - Java SDK [https://github.com/wink-travel/trip-pay-sdk-java](https://github.com/wink-travel/trip-pay-sdk-java)  # Usage These features are made available to you via a [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer). This API is language agnostic. We will link to SDKs for the most popular programming languages on this page as they become available.  ## Versioning We chose to version our endpoints in a way that we hope affects your integration with us the least. You request the version of our API you wish to work with via the `Wink-Version` header. When it's time for you to upgrade, you only have to change the version number to get access to our updated endpoints.  ## Release history - Follow updates on Github: https://github.com/wink-travel/wink-sdk-java/blob/master/CHANGELOG.md 

    The version of the OpenAPI document: 30.9.11
    Contact: bjorn@wink.travel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trip_pay_payment.api.contract_api import ContractApi


class TestContractApi(unittest.TestCase):
    """ContractApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContractApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_booking_contract(self) -> None:
        """Test case for cancel_booking_contract

        Cancel booking
        """
        pass

    def test_cancel_group_booking_contract(self) -> None:
        """Test case for cancel_group_booking_contract

        Cancel group bookings
        """
        pass

    def test_create_payable_contracts(self) -> None:
        """Test case for create_payable_contracts

        Create payable contracts
        """
        pass

    def test_immediate_group_refund(self) -> None:
        """Test case for immediate_group_refund

        Immediate group refund
        """
        pass

    def test_immediate_refund(self) -> None:
        """Test case for immediate_refund

        Immediate refund
        """
        pass

    def test_is_contract_cancellable(self) -> None:
        """Test case for is_contract_cancellable

        Contract cancellable
        """
        pass

    def test_is_group_contract_cancellable(self) -> None:
        """Test case for is_group_contract_cancellable

        Group contract cancellable
        """
        pass

    def test_request_refund(self) -> None:
        """Test case for request_refund

        Request refund
        """
        pass

    def test_show_aggregate_booking_contract_data(self) -> None:
        """Test case for show_aggregate_booking_contract_data

        Retrieve aggregate beneficiary data
        """
        pass

    def test_show_aggregate_cancellation_data(self) -> None:
        """Test case for show_aggregate_cancellation_data

        Retrieve aggregate cancellation data
        """
        pass

    def test_show_capture_currencies(self) -> None:
        """Test case for show_capture_currencies

        Retrieve capture currencies
        """
        pass

    def test_show_contract(self) -> None:
        """Test case for show_contract

        Retrieve single contract
        """
        pass

    def test_show_contract_for_external_account(self) -> None:
        """Test case for show_contract_for_external_account

        Retrieve single contract for external account
        """
        pass

    def test_show_contract_funds(self) -> None:
        """Test case for show_contract_funds

        Retrieve contract funds
        """
        pass

    def test_show_contract_grid(self) -> None:
        """Test case for show_contract_grid

        Retrieve contract grid
        """
        pass

    def test_show_contracts(self) -> None:
        """Test case for show_contracts

        Retrieve multiple contracts
        """
        pass

    def test_show_external_contract(self) -> None:
        """Test case for show_external_contract

        Retrieve single contract for external
        """
        pass

    def test_show_payable_contracts(self) -> None:
        """Test case for show_payable_contracts

        Load payable contracts
        """
        pass


if __name__ == '__main__':
    unittest.main()
